@@ -947,12 +947,12 @@ class LogicalLineFinderTest(unittest.TestCase):
         self.assertEqual([1, 2, 4], list(line_finder.generate_starts()))
 
     def test_generating_line_starts2(self):
-        code = "a = 1\na = 2\n\na = \\ 3\n"
+        code = "a = 1\na = 2\n\na = \\\n 3\n"
         line_finder = self._logical_finder(code)
         self.assertEqual([2, 4], list(line_finder.generate_starts(2)))
 
     def test_generating_line_starts3(self):
-        code = "a = 1\na = 2\n\na = \\ 3\n"
+        code = "a = 1\na = 2\n\na = \\\n 3\n"
         line_finder = self._logical_finder(code)
         self.assertEqual([2], list(line_finder.generate_starts(2, 3)))
 
