@@ -1,29 +1,20 @@
 import os.path
+import unittest
 from textwrap import dedent
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
 from rope.base import exceptions
 from rope.contrib.codeassist import (
-    get_definition_location,
-    get_doc,
-    starting_expression,
     code_assist,
-    sorted_proposals,
-    starting_offset,
     get_calltip,
     get_canonical_path,
+    get_definition_location,
+    get_doc,
+    sorted_proposals,
+    starting_expression,
+    starting_offset,
 )
 from ropetest import testutils
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 
 class CodeAssistTest(unittest.TestCase):
     def setUp(self):
@@ -734,7 +725,7 @@ class CodeAssistTest(unittest.TestCase):
             def foo():
               u"юникод-объект"''')
         doc = get_doc(self.project, src, src.index("foo") + 1)
-        self.assertTrue(isinstance(doc, unicode))
+        self.assertTrue(isinstance(doc, str))
         self.assertTrue("юникод-объект" in doc)
 
     def test_get_pydoc_utf8_bytestring(self):
@@ -743,7 +734,7 @@ class CodeAssistTest(unittest.TestCase):
             def foo():
               "байтстринг"''')
         doc = get_doc(self.project, src, src.index("foo") + 1)
-        self.assertTrue(isinstance(doc, unicode))
+        self.assertTrue(isinstance(doc, str))
         self.assertTrue("байтстринг" in doc)
 
     def test_get_pydoc_for_functions(self):
@@ -843,7 +834,7 @@ class CodeAssistTest(unittest.TestCase):
         result = self._assist(code, code.index("a_v") + 3)
         self.assert_completion_in_result("a_var", "global", result)
 
-    def test_completing_in_uncomplete_try_blocks(self):
+    def test_completing_in_incomplete_try_blocks(self):
         code = dedent("""\
             try:
                 a_var = 10
@@ -851,7 +842,7 @@ class CodeAssistTest(unittest.TestCase):
         result = self._assist(code)
         self.assert_completion_in_result("a_var", "global", result)
 
-    def test_completing_in_uncomplete_try_blocks_in_functions(self):
+    def test_completing_in_incomplete_try_blocks_in_functions(self):
         code = dedent("""\
             def a_func():
                 try:
@@ -903,7 +894,7 @@ class CodeAssistTest(unittest.TestCase):
         result = self._assist(code, code.rindex("a_") + 2)
         self.assert_completion_in_result("a_var", "global", result)
 
-    def test_completing_ifs_in_uncomplete_try_blocks(self):
+    def test_completing_ifs_in_incomplete_try_blocks(self):
         code = dedent("""\
             try:
                 if True:
@@ -912,7 +903,7 @@ class CodeAssistTest(unittest.TestCase):
         result = self._assist(code)
         self.assert_completion_in_result("a_var", "global", result)
 
-    def test_completing_ifs_in_uncomplete_try_blocks2(self):
+    def test_completing_ifs_in_incomplete_try_blocks2(self):
         code = dedent("""\
             try:
                 if True:
@@ -921,7 +912,7 @@ class CodeAssistTest(unittest.TestCase):
         result = self._assist(code)
         self.assert_completion_in_result("a_var", "global", result)
 
-    def test_completing_excepts_in_uncomplete_try_blocks(self):
+    def test_completing_excepts_in_incomplete_try_blocks(self):
         code = dedent("""\
             try:
                 pass
@@ -1162,7 +1153,7 @@ class CodeAssistTest(unittest.TestCase):
         self.assert_completion_in_result("GlobalClass", "global", result, type="class")
 
     def test_builtin_class_completion_proposal(self):
-        for varname in ("object", "dict", "file"):
+        for varname in ("object", "dict"):
             result = self._assist(varname[0])
             self.assert_completion_in_result(varname, "builtin", result, type="class")
 
@@ -1196,6 +1187,12 @@ class CodeAssistTest(unittest.TestCase):
             self.assert_completion_in_result(
                 expected, "builtin", result, type="function"
             )
+        code2 = "o"
+        result = self._assist(code2)
+        for expected in ("open",):
+            self.assert_completion_in_result(
+                expected, "builtin", result, type="function"
+            )
 
     def test_attribute_function_completion_proposal(self):
         code = dedent("""\
@@ -1349,7 +1346,7 @@ class CodeAssistInProjectsTest(unittest.TestCase):
 
     def tearDown(self):
         testutils.remove_project(self.project)
-        super(self.__class__, self).tearDown()
+        super().tearDown()
 
     def _assist(self, code, resource=None, **kwds):
         return code_assist(self.project, code, len(code), resource, **kwds)
@@ -1423,7 +1420,7 @@ class CodeAssistInProjectsTest(unittest.TestCase):
         self.assert_completion_in_result("sample_func", "imported", result)
         self.assert_completion_in_result("sample_var", "imported", result)
 
-    def test_from_import_star_not_imporing_underlined(self):
+    def test_from_import_star_not_importing_underlined(self):
         code = dedent("""\
             from samplemod import *
             _under""")
