@@ -1,11 +1,7 @@
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
+import unittest
 from textwrap import dedent
 
-from rope.refactor.importutils import ImportTools, importinfo, add_import
+from rope.refactor.importutils import ImportTools, add_import, importinfo
 from ropetest import testutils
 
 
@@ -110,7 +106,6 @@ class ImportUtilsTest(unittest.TestCase):
             "from pkg1 import *", imports[0].import_info.get_import_statement()
         )
 
-    @testutils.only_for("2.5")
     def test_get_import_statements_for_new_relatives(self):
         self.mod2.write("from .mod3 import x\n")
         pymod = self.project.get_module("pkg2.mod2")
@@ -908,6 +903,13 @@ class ImportUtilsTest(unittest.TestCase):
         changed_module = self.import_tools.froms_to_imports(pymod)
         self.assertEqual("import os\nos.path.exists('.')\n", changed_module)
 
+
+    def test_transforming_froms_to_normal_kwarg_with_same_name(self):
+        self.mod.write("from os import path\nfoo(path=path.join('a', 'b'))\n")
+        pymod = self.project.get_pymodule(self.mod)
+        changed_module = self.import_tools.froms_to_imports(pymod)
+        self.assertEqual("import os\nfoo(path=os.path.join('a', 'b'))\n", changed_module)
+
     def test_transform_relatives_imports_to_abs_imports_doing_nothing(self):
         self.mod2.write("from pkg1 import mod1\nimport mod1\n")
         pymod = self.project.get_pymodule(self.mod2)
@@ -935,7 +937,6 @@ class ImportUtilsTest(unittest.TestCase):
             self.import_tools.relatives_to_absolutes(pymod),
         )
 
-    @testutils.only_for("2.5")
     def test_transform_rel_imports_to_abs_imports_for_new_relatives(self):
         self.mod3.write(dedent("""\
             def a_func():
@@ -1620,12 +1621,12 @@ class ImportUtilsTest(unittest.TestCase):
     def test_sorting_future_imports(self):
         self.mod.write(dedent("""\
             import os
-            from __future__ import devision
+            from __future__ import division
         """))
         pymod = self.project.get_module("mod")
         self.assertEqual(
             dedent("""\
-                from __future__ import devision
+                from __future__ import division
 
                 import os
             """),
