@@ -1,11 +1,7 @@
 import sys
+import unittest
 from textwrap import dedent
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
 import rope.base.codeanalyze
 import rope.refactor.occurrences
 from rope.refactor import rename
@@ -35,6 +31,21 @@ class RenameRefactoringTest(unittest.TestCase):
         changes = Rename(self.project, resource, offset).get_changes(new_name, **kwds)
         self.project.do(changes)
 
+    def test_local_variable_but_not_parameter(self):
+        code = dedent("""\
+            a = 10
+            foo = dict(a=a)
+        """)
+
+        refactored = self._local_rename(code, 1, "new_a")
+        self.assertEqual(
+            dedent("""\
+                new_a = 10
+                foo = dict(a=new_a)
+            """),
+            refactored,
+        )
+
     def test_simple_global_variable_renaming(self):
         refactored = self._local_rename("a_var = 20\n", 2, "new_var")
         self.assertEqual("new_var = 20\n", refactored)
@@ -260,7 +271,7 @@ class RenameRefactoringTest(unittest.TestCase):
         """)
         self.assertEqual(expected, refactored)
 
-    def test_rename_functions_parameters_and_occurences_in_other_modules(self):
+    def test_rename_functions_parameters_and_occurrences_in_other_modules(self):
         mod1 = testutils.create_module(self.project, "mod1")
         mod2 = testutils.create_module(self.project, "mod2")
         mod1.write(dedent("""\
@@ -293,7 +304,6 @@ class RenameRefactoringTest(unittest.TestCase):
         )
         self.assertEqual("is_replace = True\n'ali'.\\\nreplace\n", refactored)
 
-    @testutils.only_for("3.6")
     def test_renaming_occurrence_in_f_string(self):
         code = dedent("""\
             a_var = 20
@@ -306,7 +316,6 @@ class RenameRefactoringTest(unittest.TestCase):
         refactored = self._local_rename(code, 2, "new_var")
         self.assertEqual(expected, refactored)
 
-    @testutils.only_for("3.6")
     def test_renaming_occurrence_in_nested_f_string(self):
         code = dedent("""\
             a_var = 20
@@ -319,7 +328,6 @@ class RenameRefactoringTest(unittest.TestCase):
         refactored = self._local_rename(code, 2, "new_var")
         self.assertEqual(expected, refactored)
 
-    @testutils.only_for("3.6")
     def test_not_renaming_string_contents_in_f_string(self):
         refactored = self._local_rename(
             "a_var = 20\na_string=f'{\"a_var\"}'\n", 2, "new_var"
@@ -432,7 +440,6 @@ class RenameRefactoringTest(unittest.TestCase):
             refactored,
         )
 
-    @testutils.only_for("3.5")
     def test_renaming_async_function(self):
         code = dedent("""\
             async def a_func():
@@ -447,7 +454,6 @@ class RenameRefactoringTest(unittest.TestCase):
             refactored,
         )
 
-    @testutils.only_for("3.5")
     def test_renaming_await(self):
         code = dedent("""\
             async def b_func():
@@ -866,7 +872,6 @@ class RenameRefactoringTest(unittest.TestCase):
             refactored,
         )
 
-    @testutils.only_for("3.5")
     def test_renaming_async_for_loop_variable(self):
         code = dedent("""\
             async def func():
@@ -883,7 +888,6 @@ class RenameRefactoringTest(unittest.TestCase):
             refactored,
         )
 
-    @testutils.only_for("3.5")
     def test_renaming_async_with_context_manager(self):
         code = dedent("""\
             def a_cm(): pass
@@ -896,7 +900,6 @@ class RenameRefactoringTest(unittest.TestCase):
                 async with another_cm() as x: pass""")
         self.assertEqual(refactored, expected)
 
-    @testutils.only_for("3.5")
     def test_renaming_async_with_as_variable(self):
         code = dedent("""\
             async def func():
@@ -1410,7 +1413,6 @@ class RenameRefactoringTest(unittest.TestCase):
         )
 
     # XXX: with variables should not leak
-    @testutils.only_for("2.5")
     def xxx_test_with_statement_variables_should_not_leak(self):
         code = dedent("""\
             f = 1
