@@ -1,12 +1,7 @@
 import os
+import unittest
 from textwrap import dedent
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
-
 from rope.base import exceptions
 from ropetest import testutils
 
